@@ -1,3 +1,5 @@
+from __future__ import annotations
+
 from timely_beliefs.beliefs.classes import BeliefsDataFrame
 from typing import List, Sequence, Tuple, Union
 import copy
@@ -54,8 +56,8 @@ def contains_empty_items(groups: List[List[str]]):
 
 
 def parse_as_list(
-    connection: Union[Sequence[Union[str, float]], str, float], of_type: type = None
-) -> Sequence[Union[str, float, None]]:
+    connection: str | float | Sequence[str | float], of_type: type | None = None
+) -> Sequence[str | float | None]:
     """
     Return a list of connections (or values), even if it's just one connection (or value)
     """
@@ -79,7 +81,7 @@ def parse_as_list(
     return connections
 
 
-# TODO: we should be using webargs to get data from a request, it's more descriptive and has error handling
+# TODO: deprecate ― we should be using webargs to get data from a request, it's more descriptive and has error handling
 def get_form_from_request(_request) -> Union[dict, None]:
     if _request.method == "GET":
         d = _request.args.to_dict(
@@ -141,7 +143,7 @@ def groups_to_dict(
     connection_groups: List[str],
     value_groups: List[List[str]],
     generic_asset_type_name: str,
-    plural_name: str = None,
+    plural_name: str | None = None,
     groups_name="groups",
 ) -> dict:
     """Put the connections and values in a dictionary and simplify if groups have identical values and/or if there is
@@ -245,7 +247,7 @@ def unique_ever_seen(iterable: Sequence, selector: Sequence):
 def message_replace_name_with_ea(message_with_connections_as_asset_names: dict) -> dict:
     """
     For each connection in the message specified by a name, replace that name with the correct entity address.
-    TODO: This function is now only used in tests and should go (also asset_replace_name_with_id)
+    TODO: Deprecated. This function is now only used in tests of deprecated API versions and should go (also asset_replace_name_with_id)
     """
     message_with_connections_as_eas = copy.deepcopy(
         message_with_connections_as_asset_names
@@ -343,7 +345,7 @@ def get_sensor_by_generic_asset_type_and_location(
 
 
 def enqueue_forecasting_jobs(
-    forecasting_jobs: List[Job] = None,
+    forecasting_jobs: list[Job] | None = None,
 ):
     """Enqueue forecasting jobs.
 
@@ -355,7 +357,7 @@ def enqueue_forecasting_jobs(
 
 def save_and_enqueue(
     data: Union[BeliefsDataFrame, List[BeliefsDataFrame]],
-    forecasting_jobs: List[Job] = None,
+    forecasting_jobs: list[Job] | None = None,
     save_changed_beliefs_only: bool = True,
 ) -> ResponseTuple:
 
@@ -409,11 +411,7 @@ def save_to_db(
 
         if save_changed_beliefs_only:
             # Drop beliefs that haven't changed
-            timed_values = (
-                timed_values.convert_index_from_belief_horizon_to_time()
-                .groupby(level=["belief_time", "source"], as_index=False)
-                .apply(drop_unchanged_beliefs)
-            )
+            timed_values = drop_unchanged_beliefs(timed_values)
 
             # Work around bug in which groupby still introduces an index level, even though we asked it not to
             if None in timed_values.index.names:
