@@ -35,7 +35,6 @@ from flexmeasures.data.models.time_series import Sensor
 from flexmeasures.data.queries.utils import simplify_index
 from flexmeasures.data.schemas.sensors import SensorSchema, SensorIdField
 from flexmeasures.data.schemas.times import AwareDateTimeField, PlanningDurationField
-from flexmeasures.data.schemas.scheduling import FlexContextSchema
 from flexmeasures.data.services.sensors import get_sensors
 from flexmeasures.data.services.scheduling import (
     create_scheduling_job,
@@ -240,9 +239,7 @@ class SensorAPI(FlaskView):
             "prefer_charging_sooner": fields.Bool(
                 data_key="prefer-charging-sooner", required=False
             ),
-            "flex_context": fields.Nested(
-                FlexContextSchema, required=False, data_key="flex-context"
-            ),
+            "flex_context": fields.Dict(required=False, data_key="flex-context"),
             "consumption_price_sensor": SensorIdField(
                 data_key="consumption-price-sensor", required=False
             ),
