@@ -51,6 +51,23 @@ FIELD_DEFINITIONS = {
         type="nominal",
         title="Time and date",
     ),
+    "source_name_and_id": dict(
+        field="source_name_and_id",
+        type="nominal",
+        title="Source",
+    ),
+}
+REPLAY_RULER = {
+    "data": {"name": "replay"},
+    "mark": {
+        "type": "rule",
+    },
+    "encoding": {
+        "x": {
+            "field": "belief_time",
+            "type": "temporal",
+        },
+    },
 }
 SHADE_LAYER = {
     "mark": {
