@@ -1,4 +1,6 @@
-from typing import Optional, Union, List
+from __future__ import annotations
+
+from collections.abc import Sequence
 
 from flask import current_app
 from flexmeasures.data import db
@@ -7,18 +9,26 @@ from flexmeasures.data.models.data_sources import DataSource
 
 
 def parse_source_arg(
-    source: Optional[
-        Union[DataSource, List[DataSource], int, List[int], str, List[str]]
-    ]
-) -> Optional[List[DataSource]]:
-    """Parse the "source" argument by looking up DataSources corresponding to any given ids or names."""
+    source: DataSource
+    | int
+    | str
+    | Sequence[DataSource]
+    | Sequence[int]
+    | Sequence[str]
+    | None,
+) -> list[DataSource] | None:
+    """Parse the "source" argument by looking up DataSources corresponding to any given ids or names.
+
+    Passes None as is (i.e. no source argument is given).
+    Accepts ids and names as list or tuples, always converting them to a list.
+    """
     if source is None:
         return source
-    if not isinstance(source, list):
+    if isinstance(source, (DataSource, str, int)):
         sources = [source]
     else:
         sources = source
-    parsed_sources: List[DataSource] = []
+    parsed_sources: list[DataSource] = []
     for source in sources:
         if isinstance(source, int):
             parsed_source = (
