@@ -339,6 +339,8 @@ class Sensor(db.Model, tb.SensorDBMixin, AuthModelMixin):
         )
         if as_json:
             df = bdf.reset_index()
+            df["sensor"] = self
+            df["sensor"] = df["sensor"].apply(lambda x: x.to_dict())
             df["source"] = df["source"].apply(lambda x: x.to_dict())
             return df.to_json(orient="records")
         return bdf
@@ -480,6 +482,15 @@ class Sensor(db.Model, tb.SensorDBMixin, AuthModelMixin):
     def __repr__(self) -> str:
         return f"<Sensor {self.id}: {self.name}, unit: {self.unit} res.: {self.event_resolution}>"
 
+    def __str__(self) -> str:
+        return self.name
+
+    def to_dict(self) -> dict:
+        return dict(
+            id=self.id,
+            name=self.name,
+        )
+
     @classmethod
     def find_closest(
         cls, generic_asset_type_name: str, sensor_name: str, n: int = 1, **kwargs
@@ -600,7 +611,10 @@ class TimedBelief(db.Model, tb.TimedBeliefDBMixin):
 
         *  If user_source_ids is specified, the "user" source type is automatically included (and not excluded).
            Somewhat redundant, though still allowed, is to set both source_types and exclude_source_types.
-        ** Note that timely-beliefs converts string resolutions to datetime.timedelta objects (see https://github.com/SeitaBV/timely-beliefs/issues/13).
+        ** Note that:
+           - timely-beliefs converts string resolutions to datetime.timedelta objects (see https://github.com/SeitaBV/timely-beliefs/issues/13).
+           - for sensors recording non-instantaneous data: updates both the event frequency and the event resolution
+           - for sensors recording instantaneous data: updates only the event frequency (and event resolution remains 0)
         """
         # todo: deprecate the 'sensor' argument in favor of 'sensors' (announced v0.8.0)
         sensors = tb_utils.replace_deprecated_argument(
@@ -641,8 +655,9 @@ class TimedBelief(db.Model, tb.TimedBeliefDBMixin):
             bdf = cls.search_session(
                 session=db.session,
                 sensor=sensor,
-                event_starts_after=event_starts_after,
-                event_ends_before=event_ends_before,
+                # Workaround (1st half) for https://github.com/FlexMeasures/flexmeasures/issues/484
+                event_ends_after=event_starts_after,
+                event_starts_before=event_ends_before,
                 beliefs_after=beliefs_after,
                 beliefs_before=beliefs_before,
                 horizons_at_least=horizons_at_least,
@@ -679,6 +694,9 @@ class TimedBelief(db.Model, tb.TimedBeliefDBMixin):
                 bdf = bdf.resample_events(
                     resolution, keep_only_most_recent_belief=most_recent_beliefs_only
                 )
+                # Workaround (2nd half) for https://github.com/FlexMeasures/flexmeasures/issues/484
+                bdf = bdf[bdf.event_starts >= event_starts_after]
+                bdf = bdf[bdf.event_ends <= event_ends_before]
             bdf_dict[bdf.sensor.name] = bdf
 
         if sum_multiple:
