@@ -1,3 +1,5 @@
+from __future__ import annotations
+
 from typing import Optional, Union
 from datetime import datetime
 
@@ -36,7 +38,7 @@ class UserForm(FlaskForm):
     active = BooleanField("Activation Status", validators=[DataRequired()])
 
 
-def render_user(user: Optional[User], asset_count: int = 0, msg: str = None):
+def render_user(user: User | None, asset_count: int = 0, msg: str | None = None):
     user_form = UserForm()
     user_form.process(obj=user)
     return render_flexmeasures_template(
@@ -59,10 +61,9 @@ def process_internal_api_response(
         role_ids = tuple(user_data.get("flexmeasures_roles", []))
         user_data["flexmeasures_roles"] = Role.query.filter(Role.id.in_(role_ids)).all()
         user_data.pop("status", None)  # might have come from requests.response
-        if "last_login_at" in user_data and user_data["last_login_at"] is not None:
-            user_data["last_login_at"] = datetime.fromisoformat(
-                user_data["last_login_at"]
-            )
+        for date_field in ("last_login_at", "last_seen_at"):
+            if date_field in user_data and user_data[date_field] is not None:
+                user_data[date_field] = datetime.fromisoformat(user_data[date_field])
         if user_id:
             user_data["id"] = user_id
         if make_obj:
