@@ -6,7 +6,6 @@ from typing import Tuple, List, Optional
 from datetime import datetime
 
 from flask import render_template, request, session, current_app
-from bokeh.resources import CDN
 from flask_security.core import current_user
 from werkzeug.exceptions import BadRequest
 import iso8601
@@ -54,12 +53,6 @@ def render_flexmeasures_template(html_filename: str, **variables):
     if "show_datepicker" not in variables:
         variables["show_datepicker"] = variables["page"] in ("analytics", "portfolio")
 
-    variables["contains_plots"] = False
-    if any([n.endswith(("plots_div", "plots_divs")) for n in variables.keys()]):
-        variables["contains_plots"] = True
-        variables["bokeh_css_resources"] = CDN.render_css()
-        variables["bokeh_js_resources"] = CDN.render_js()
-
     variables["resolution"] = session.get("resolution", "")
     variables["resolution_human"] = time_utils.freq_label_to_human_readable_label(
         session.get("resolution", "")
