@@ -44,13 +44,13 @@ def integrate_time_series(
     down_efficiency: float | pd.Series = 1,
     decimal_precision: int | None = None,
 ) -> pd.Series:
-    """Integrate time series of length n and closed="left" (representing a flow)
-    to a time series of length n+1 and closed="both" (representing a stock),
+    """Integrate time series of length n and inclusive="left" (representing a flow)
+    to a time series of length n+1 and inclusive="both" (representing a stock),
     given an initial stock (i.e. the constant of integration).
     The unit of time is hours: i.e. the stock unit is flow unit times hours (e.g. a flow in kW becomes a stock in kWh).
     Optionally, set a decimal precision to round off the results (useful for tests failing over machine precision).
 
-    >>> s = pd.Series([1, 2, 3, 4], index=pd.date_range(datetime(2001, 1, 1, 5), datetime(2001, 1, 1, 6), freq=timedelta(minutes=15), closed="left"))
+    >>> s = pd.Series([1, 2, 3, 4], index=pd.date_range(datetime(2001, 1, 1, 5), datetime(2001, 1, 1, 6), freq=timedelta(minutes=15), inclusive="left"))
     >>> integrate_time_series(s, 10)
         2001-01-01 05:00:00    10.00
         2001-01-01 05:15:00    10.25
@@ -59,7 +59,7 @@ def integrate_time_series(
         2001-01-01 06:00:00    12.50
         Freq: D, dtype: float64
 
-    >>> s = pd.Series([1, 2, 3, 4], index=pd.date_range(datetime(2001, 1, 1, 5), datetime(2001, 1, 1, 7), freq=timedelta(minutes=30), closed="left"))
+    >>> s = pd.Series([1, 2, 3, 4], index=pd.date_range(datetime(2001, 1, 1, 5), datetime(2001, 1, 1, 7), freq=timedelta(minutes=30), inclusive="left"))
     >>> integrate_time_series(s, 10)
         2001-01-01 05:00:00    10.0
         2001-01-01 05:30:00    10.5
